@@ -16,7 +16,6 @@
 import functools
 import os
 from os.path import isdir  # tighter scoped import for mocking
-import time
 
 import six
 from six.moves.configparser import ConfigParser, NoSectionError, NoOptionError
@@ -303,15 +302,19 @@ def valid_timestamp(request):
 
 def check_delete_headers(request):
     """
-    Validate if 'x-delete' headers are have correct values
-    values should be positive integers and correspond to
-    a time in the future.
+    Check that 'x-delete-after' and 'x-delete-at' headers have valid values.
+    Values should be positive integers and correspond to a time greater than
+    the request timestamp.
+
+    If the 'x-delete-after' header is found then its value is used to compute
+    an 'x-delete-at' value which takes precedence over any existing
+    'x-delete-at' header.
 
     :param request: the swob request object
-
-    :returns: HTTPBadRequest in case of invalid values
-              or None if values are ok
+    :raises: HTTPBadRequest in case of invalid values
+    :returns: the swob request object
     """
+    now = float(valid_timestamp(request))
     if 'x-delete-after' in request.headers:
         try:
             x_delete_after = int(request.headers['x-delete-after'])
@@ -319,13 +322,14 @@ def check_delete_headers(request):
             raise HTTPBadRequest(request=request,
                                  content_type='text/plain',
                                  body='Non-integer X-Delete-After')
-        actual_del_time = time.time() + x_delete_after
-        if actual_del_time < time.time():
+        actual_del_time = utils.normalize_delete_at_timestamp(
+            now + x_delete_after)
+        if int(actual_del_time) <= now:
             raise HTTPBadRequest(request=request,
                                  content_type='text/plain',
                                  body='X-Delete-After in past')
-        request.headers['x-delete-at'] = utils.normalize_delete_at_timestamp(
-            actual_del_time)
+        request.headers['x-delete-at'] = actual_del_time
+        del request.headers['x-delete-after']
 
     if 'x-delete-at' in request.headers:
         try:
@@ -335,7 +339,7 @@ def check_delete_headers(request):
             raise HTTPBadRequest(request=request, content_type='text/plain',
                                  body='Non-integer X-Delete-At')
 
-        if x_delete_at < time.time() and not utils.config_true_value(
+        if x_delete_at <= now and not utils.config_true_value(
                 request.headers.get('x-backend-replication', 'f')):
             raise HTTPBadRequest(request=request, content_type='text/plain',
                                  body='X-Delete-At in past')
