@@ -333,7 +333,9 @@ class DatabaseBroker(object):
             exc_hint = 'malformed'
         elif 'malformed database schema' in str(exc_value):
             exc_hint = 'malformed'
-        elif 'file is encrypted or is not a database' in str(exc_value):
+        elif ' is not a database' in str(exc_value):
+            # older versions said 'file is not a database'
+            # now 'file is encrypted or is not a database'
             exc_hint = 'corrupted'
         elif 'disk I/O error' in str(exc_value):
             exc_hint = 'disk error while accessing'
