@@ -260,7 +260,7 @@ class _StaticWebContext(WSGIContext):
             env, 'GET', '/%s/%s/%s' % (
                 self.version, self.account, self.container),
             self.agent, swift_source='SW')
-        tmp_env['QUERY_STRING'] = 'delimiter=/&format=json'
+        tmp_env['QUERY_STRING'] = 'delimiter=/'
         if prefix:
             tmp_env['QUERY_STRING'] += '&prefix=%s' % quote(prefix)
         else:
@@ -465,8 +465,8 @@ class _StaticWebContext(WSGIContext):
                     env, 'GET', '/%s/%s/%s' % (
                         self.version, self.account, self.container),
                     self.agent, swift_source='SW')
-                tmp_env['QUERY_STRING'] = 'limit=1&format=json&delimiter' \
-                    '=/&limit=1&prefix=%s' % quote(self.obj + '/')
+                tmp_env['QUERY_STRING'] = 'limit=1&delimiter=/&prefix=%s' % (
+                    quote(self.obj + '/'), )
                 resp = self._app_call(tmp_env)
                 body = ''.join(resp)
                 if not is_success(self._get_status_int()) or not body or \
