@@ -30,9 +30,9 @@ from swift.common.daemon import Daemon
 class ContainerAuditor(Daemon):
     """Audit containers."""
 
-    def __init__(self, conf):
+    def __init__(self, conf, logger=None):
         self.conf = conf
-        self.logger = get_logger(conf, log_route='container-auditor')
+        self.logger = logger or get_logger(conf, log_route='container-auditor')
         self.devices = conf.get('devices', '/srv/node')
         self.mount_check = config_true_value(conf.get('mount_check', 'true'))
         self.interval = int(conf.get('interval', 1800))
@@ -116,7 +116,7 @@ class ContainerAuditor(Daemon):
                 broker.get_info()
                 self.logger.increment('passes')
                 self.container_passes += 1
-                self.logger.debug(_('Audit passed for %s'), broker)
+                self.logger.debug('Audit passed for %s', broker)
         except (Exception, Timeout):
             self.logger.increment('failures')
             self.container_failures += 1
