@@ -18,15 +18,14 @@ Pluggable Back-ends for Container Server
 
 import os
 from uuid import uuid4
-import time
 
 import six
 import six.moves.cPickle as pickle
 from six.moves import range
 import sqlite3
 
-from swift.common.utils import Timestamp, encode_timestamps, decode_timestamps, \
-    extract_swift_bytes
+from swift.common.utils import Timestamp, encode_timestamps, \
+    decode_timestamps, extract_swift_bytes
 from swift.common.db import DatabaseBroker, utf8encode
 
 
@@ -146,7 +145,7 @@ def update_new_item_from_existing(new_item, existing):
     their timestamps are newer.
 
     The multiple timestamps are encoded into a single string for storing
-    in the 'created_at' column of the the objects db table.
+    in the 'created_at' column of the objects db table.
 
     :param new_item: A dict of object update attributes
     :param existing: A dict of existing object attributes
@@ -314,7 +313,7 @@ class ContainerBroker(DatabaseBroker):
             INSERT INTO container_info (account, container, created_at, id,
                 put_timestamp, status_changed_at, storage_policy_index)
             VALUES (?, ?, ?, ?, ?, ?, ?);
-        """, (self.account, self.container, Timestamp(time.time()).internal,
+        """, (self.account, self.container, Timestamp.now().internal,
               str(uuid4()), put_timestamp, put_timestamp,
               storage_policy_index))
 
@@ -611,7 +610,7 @@ class ContainerBroker(DatabaseBroker):
         Update the container_stat policy_index and status_changed_at.
         """
         if timestamp is None:
-            timestamp = Timestamp(time.time()).internal
+            timestamp = Timestamp.now().internal
 
         def _setit(conn):
             conn.execute('''
@@ -776,7 +775,7 @@ class ContainerBroker(DatabaseBroker):
                                 marker = name[:end] + chr(ord(delimiter) + 1)
                             curs.close()
                             break
-                    elif end > 0:
+                    elif end >= 0:
                         if reverse:
                             end_marker = name[:end + 1]
                         else:
@@ -861,7 +860,7 @@ class ContainerBroker(DatabaseBroker):
                     'DELETE FROM object WHERE ' + query_mod +
                     'name=? AND storage_policy_index=?',
                     ((rec['name'], rec['storage_policy_index'])
-                     for rec in to_delete.itervalues()))
+                     for rec in to_delete.values()))
             if to_add:
                 curs.executemany(
                     'INSERT INTO object (name, created_at, size, content_type,'
@@ -870,7 +869,7 @@ class ContainerBroker(DatabaseBroker):
                     ((rec['name'], rec['created_at'], rec['size'],
                       rec['content_type'], rec['etag'], rec['deleted'],
                       rec['storage_policy_index'])
-                     for rec in to_add.itervalues()))
+                     for rec in to_add.values()))
             if source:
                 # for replication we rely on the remote end sending merges in
                 # order with no gaps to increment sync_points
