@@ -26,14 +26,13 @@ import six
 import six.moves.cPickle as pickle
 import shutil
 
-from eventlet import (GreenPile, GreenPool, Timeout, sleep, hubs, tpool,
-                      spawn)
+from eventlet import (GreenPile, GreenPool, Timeout, sleep, tpool, spawn)
 from eventlet.support.greenlets import GreenletExit
 
 from swift import gettext_ as _
 from swift.common.utils import (
     whataremyips, unlink_older_than, compute_eta, get_logger,
-    dump_recon_cache, mkdirs, config_true_value, list_from_csv, get_hub,
+    dump_recon_cache, mkdirs, config_true_value, list_from_csv,
     tpool_reraise, GreenAsyncPile, Timestamp, remove_file)
 from swift.common.header_key_dict import HeaderKeyDict
 from swift.common.bufferedhttp import http_connect
@@ -51,9 +50,6 @@ from swift.common.exceptions import ConnectionTimeout, DiskFileError, \
 SYNC, REVERT = ('sync_only', 'sync_revert')
 
 
-hubs.use_hub(get_hub())
-
-
 def _get_partners(frag_index, part_nodes):
     """
     Returns the left and right partners of the node whose index is
@@ -1097,8 +1093,9 @@ class ObjectReconstructor(Daemon):
                 self.part_count += len(partitions)
                 for partition in partitions:
                     part_path = join(obj_path, partition)
-                    if partition in ('auditor_status_ALL.json',
-                                     'auditor_status_ZBF.json'):
+                    if (partition.startswith('auditor_status_') and
+                            partition.endswith('.json')):
+                        # ignore auditor status files
                         continue
                     if not partition.isdigit():
                         self.logger.warning(
@@ -1237,8 +1234,8 @@ class ObjectReconstructor(Daemon):
             'object_reconstruction_last': time.time(),
         }
 
-        if self.reconstructor_workers > 0:
-            devices = override_devices or self.all_local_devices
+        devices = override_devices or self.all_local_devices
+        if self.reconstructor_workers > 0 and devices:
             recon_update['pid'] = os.getpid()
             recon_update = {'object_reconstruction_per_disk': {
                 d: recon_update for d in devices}}
