@@ -18,13 +18,12 @@ from swift import gettext_ as _
 from six.moves.urllib.parse import unquote
 from swift.common.utils import public, csv_append, Timestamp
 from swift.common.constraints import check_metadata
-from swift.common import constraints
 from swift.common.http import HTTP_ACCEPTED, is_success
 from swift.proxy.controllers.base import Controller, delay_denial, \
     cors_validation, set_info_cache, clear_info_cache
 from swift.common.storage_policy import POLICIES
 from swift.common.swob import HTTPBadRequest, HTTPForbidden, \
-    HTTPNotFound
+    HTTPNotFound, HTTPServerError
 
 
 class ContainerController(Controller):
@@ -151,16 +150,17 @@ class ContainerController(Controller):
         if not req.environ.get('swift_owner'):
             for key in self.app.swift_owner_headers:
                 req.headers.pop(key, None)
-        if len(self.container_name) > constraints.MAX_CONTAINER_NAME_LENGTH:
+        length_limit = self.get_name_length_limit()
+        if len(self.container_name) > length_limit:
             resp = HTTPBadRequest(request=req)
             resp.body = 'Container name length of %d longer than %d' % \
-                        (len(self.container_name),
-                         constraints.MAX_CONTAINER_NAME_LENGTH)
+                        (len(self.container_name), length_limit)
             return resp
         account_partition, accounts, container_count = \
             self.account_info(self.account_name, req)
         if not accounts and self.app.account_autocreate:
-            self.autocreate_account(req, self.account_name)
+            if not self.autocreate_account(req, self.account_name):
+                return HTTPServerError(request=req)
             account_partition, accounts, container_count = \
                 self.account_info(self.account_name, req)
         if not accounts:
