@@ -18,14 +18,13 @@
 import unittest2
 import json
 from uuid import uuid4
-from unittest2 import SkipTest
 from string import ascii_letters
 
 from six.moves import range
 from swift.common.middleware.acl import format_acl
 
 from test.functional import check_response, retry, requires_acls, \
-    load_constraint
+    load_constraint, SkipTest
 import test.functional as tf
 
 
