@@ -14,10 +14,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import unittest
 import test.functional as tf
-from test.functional.tests import Utils, Base, Base2
-from test.functional.swift_test_client import Account, Connection, \
-    ResponseError
+from test.functional.tests import Utils, Base, Base2, BaseEnv
+from test.functional.swift_test_client import Connection, ResponseError
 
 
 def setUpModule():
@@ -28,21 +28,10 @@ def tearDownModule():
     tf.teardown_package()
 
 
-class TestDloEnv(object):
+class TestDloEnv(BaseEnv):
     @classmethod
     def setUp(cls):
-        cls.conn = Connection(tf.config)
-        cls.conn.authenticate()
-
-        config2 = tf.config.copy()
-        config2['username'] = tf.config['username3']
-        config2['password'] = tf.config['password3']
-        cls.conn2 = Connection(config2)
-        cls.conn2.authenticate()
-
-        cls.account = Account(cls.conn, tf.config.get('account',
-                                                      tf.config['username']))
-        cls.account.delete_containers()
+        super(TestDloEnv, cls).setUp()
 
         cls.container = cls.account.container(Utils.create_name())
         cls.container2 = cls.account.container(Utils.create_name())
@@ -92,7 +81,6 @@ class TestDloEnv(object):
 
 class TestDlo(Base):
     env = TestDloEnv
-    set_up = False
 
     def test_get_manifest(self):
         file_item = self.env.container.file('man1')
@@ -251,9 +239,15 @@ class TestDlo(Base):
         manifest.info(hdrs={'If-None-Match': "not-%s" % etag})
         self.assert_status(200)
 
+    @unittest.skipIf('username3' not in tf.config, "Requires user 3")
     def test_dlo_referer_on_segment_container(self):
         # First the account2 (test3) should fail
-        headers = {'X-Auth-Token': self.env.conn2.storage_token,
+        config2 = tf.config.copy()
+        config2['username'] = tf.config['username3']
+        config2['password'] = tf.config['password3']
+        conn2 = Connection(config2)
+        conn2.authenticate()
+        headers = {'X-Auth-Token': conn2.storage_token,
                    'Referer': 'http://blah.example.com'}
         dlo_file = self.env.container.file("mancont2")
         self.assertRaises(ResponseError, dlo_file.read,
@@ -394,4 +388,4 @@ class TestDlo(Base):
 
 
 class TestDloUTF8(Base2, TestDlo):
-    set_up = False
+    pass
