@@ -49,16 +49,14 @@ class TestContainerFailures(ReplProbeTest):
         client.put_container(self.url, self.token, container1)
 
         # Kill container1 servers excepting two of the primaries
-        kill_nonprimary_server(cnodes, self.ipport2server, self.pids)
-        kill_server((cnodes[0]['ip'], cnodes[0]['port']),
-                    self.ipport2server, self.pids)
+        kill_nonprimary_server(cnodes, self.ipport2server)
+        kill_server((cnodes[0]['ip'], cnodes[0]['port']), self.ipport2server)
 
         # Delete container1
         client.delete_container(self.url, self.token, container1)
 
         # Restart other container1 primary server
-        start_server((cnodes[0]['ip'], cnodes[0]['port']),
-                     self.ipport2server, self.pids)
+        start_server((cnodes[0]['ip'], cnodes[0]['port']), self.ipport2server)
 
         # Create container1/object1 (allowed because at least server thinks the
         #   container exists)
@@ -89,12 +87,11 @@ class TestContainerFailures(ReplProbeTest):
         client.put_container(self.url, self.token, container1)
 
         # Kill container1 servers excepting one of the primaries
-        cnp_ipport = kill_nonprimary_server(cnodes, self.ipport2server,
-                                            self.pids)
+        cnp_ipport = kill_nonprimary_server(cnodes, self.ipport2server)
         kill_server((cnodes[0]['ip'], cnodes[0]['port']),
-                    self.ipport2server, self.pids)
+                    self.ipport2server)
         kill_server((cnodes[1]['ip'], cnodes[1]['port']),
-                    self.ipport2server, self.pids)
+                    self.ipport2server)
 
         # Delete container1 directly to the one primary still up
         direct_client.direct_delete_container(cnodes[2], cpart, self.account,
@@ -102,10 +99,10 @@ class TestContainerFailures(ReplProbeTest):
 
         # Restart other container1 servers
         start_server((cnodes[0]['ip'], cnodes[0]['port']),
-                     self.ipport2server, self.pids)
+                     self.ipport2server)
         start_server((cnodes[1]['ip'], cnodes[1]['port']),
-                     self.ipport2server, self.pids)
-        start_server(cnp_ipport, self.ipport2server, self.pids)
+                     self.ipport2server)
+        start_server(cnp_ipport, self.ipport2server)
 
         # Get to a final state
         self.get_to_final_state()
