@@ -15,11 +15,9 @@
 # limitations under the License.
 
 from io import StringIO
-from unittest import main
+from unittest import main, SkipTest
 from uuid import uuid4
 
-from nose import SkipTest
-
 from swiftclient import client
 from swiftclient.exceptions import ClientException
 
@@ -65,7 +63,7 @@ class TestObjectAsyncUpdate(ReplProbeTest):
         # In this test, we need to put container at handoff devices, so we
         # need container devices more than replica count
         if len(self.container_ring.devs) <= self.container_ring.replica_count:
-            raise SkipTest('Need devices more that replica count')
+            raise SkipTest("Need devices more that replica count")
 
         container = 'container-%s' % uuid4()
         cpart, cnodes = self.container_ring.get_nodes(self.account, container)
@@ -237,8 +235,7 @@ class TestUpdateOverridesEC(ECProbeTest):
         self.assertFalse(direct_client.direct_get_container(
             cnodes[0], cpart, self.account, 'c1')[1])
 
-        # use internal client for POST so we can force fast-post mode
-        int_client = self.make_internal_client(object_post_as_copy=False)
+        int_client = self.make_internal_client()
         int_client.set_object_metadata(
             self.account, 'c1', 'o1', {'X-Object-Meta-Fruit': 'Tomato'})
         self.assertEqual(
@@ -296,8 +293,7 @@ class TestUpdateOverridesEC(ECProbeTest):
                           content_type='test/ctype')
         meta = client.head_object(self.url, self.token, 'c1', 'o1')
 
-        # use internal client for POST so we can force fast-post mode
-        int_client = self.make_internal_client(object_post_as_copy=False)
+        int_client = self.make_internal_client()
         int_client.set_object_metadata(
             self.account, 'c1', 'o1', {'X-Object-Meta-Fruit': 'Tomato'})
         self.assertEqual(
