@@ -19,7 +19,6 @@ from __future__ import print_function
 import os
 import copy
 import logging
-import errno
 from six.moves import range
 from six import BytesIO
 import sys
@@ -32,11 +31,14 @@ import time
 import eventlet
 from eventlet import greenpool, debug as eventlet_debug
 from eventlet.green import socket
-from tempfile import mkdtemp
+from tempfile import mkdtemp, mkstemp, gettempdir
 from shutil import rmtree
 import signal
 import json
 import random
+import errno
+import xattr
+
 
 from swift.common.utils import Timestamp, NOTICE
 from test import get_config
@@ -57,7 +59,12 @@ import six.moves.cPickle as pickle
 from gzip import GzipFile
 import mock as mocklib
 import inspect
-from nose import SkipTest
+import unittest
+import unittest2
+
+
+class SkipTest(unittest2.SkipTest, unittest.SkipTest):
+    pass
 
 EMPTY_ETAG = md5().hexdigest()
 
@@ -402,36 +409,6 @@ def tmpfile(content):
     finally:
         os.unlink(file_name)
 
-xattr_data = {}
-
-
-def _get_inode(fd):
-    if not isinstance(fd, int):
-        try:
-            fd = fd.fileno()
-        except AttributeError:
-            return os.stat(fd).st_ino
-    return os.fstat(fd).st_ino
-
-
-def _setxattr(fd, k, v):
-    inode = _get_inode(fd)
-    data = xattr_data.get(inode, {})
-    data[k] = v
-    xattr_data[inode] = data
-
-
-def _getxattr(fd, k):
-    inode = _get_inode(fd)
-    data = xattr_data.get(inode, {}).get(k)
-    if not data:
-        raise IOError(errno.ENODATA, "Fake IOError")
-    return data
-
-import xattr
-xattr.setxattr = _setxattr
-xattr.getxattr = _getxattr
-
 
 @contextmanager
 def temptree(files, contents=''):
@@ -709,49 +686,28 @@ def quiet_eventlet_exceptions():
         eventlet_debug.hub_exceptions(orig_state)
 
 
-class MockTrue(object):
+@contextmanager
+def mock_check_drive(isdir=False, ismount=False):
     """
-    Instances of MockTrue evaluate like True
-    Any attr accessed on an instance of MockTrue will return a MockTrue
-    instance. Any method called on an instance of MockTrue will return
-    a MockTrue instance.
+    All device/drive/mount checking should be done through the constraints
+    module. If we keep the mocking consistently within that module, we can
+    keep our tests robust to further rework on that interface.
 
-    >>> thing = MockTrue()
-    >>> thing
-    True
-    >>> thing == True # True == True
-    True
-    >>> thing == False # True == False
-    False
-    >>> thing != True # True != True
-    False
-    >>> thing != False # True != False
-    True
-    >>> thing.attribute
-    True
-    >>> thing.method()
-    True
-    >>> thing.attribute.method()
-    True
-    >>> thing.method().attribute
-    True
+    Replace the constraint modules underlying os calls with mocks.
 
+    :param isdir: return value of constraints isdir calls, default False
+    :param ismount: return value of constraints ismount calls, default False
+    :returns: a dict of constraint module mocks
     """
-
-    def __getattribute__(self, *args, **kwargs):
-        return self
-
-    def __call__(self, *args, **kwargs):
-        return self
-
-    def __repr__(*args, **kwargs):
-        return repr(True)
-
-    def __eq__(self, other):
-        return other is True
-
-    def __ne__(self, other):
-        return other is not True
+    mock_base = 'swift.common.constraints.'
+    with mocklib.patch(mock_base + 'isdir') as mock_isdir, \
+            mocklib.patch(mock_base + 'utils.ismount') as mock_ismount:
+        mock_isdir.return_value = isdir
+        mock_ismount.return_value = ismount
+        yield {
+            'isdir': mock_isdir,
+            'ismount': mock_ismount,
+        }
 
 
 @contextmanager
@@ -1310,3 +1266,51 @@ def fake_ec_node_response(node_frags, policy):
         return StubResponse(200, body, headers)
 
     return get_response
+
+
+supports_xattr_cached_val = None
+
+
+def xattr_supported_check():
+    """
+    This check simply sets more than 4k of metadata on a tempfile and
+    returns True if it worked and False if not.
+
+    We want to use *more* than 4k of metadata in this check because
+    some filesystems (eg ext4) only allow one blocksize worth of
+    metadata. The XFS filesystem doesn't have this limit, and so this
+    check returns True when TMPDIR is XFS. This check will return
+    False under ext4 (which supports xattrs <= 4k) and tmpfs (which
+    doesn't support xattrs at all).
+
+    """
+    global supports_xattr_cached_val
+
+    if supports_xattr_cached_val is not None:
+        return supports_xattr_cached_val
+
+    # assume the worst -- xattrs aren't supported
+    supports_xattr_cached_val = False
+
+    big_val = 'x' * (4096 + 1)  # more than 4k of metadata
+    try:
+        fd, tmppath = mkstemp()
+        xattr.setxattr(fd, 'user.swift.testing_key', big_val)
+    except IOError as e:
+        if errno.errorcode.get(e.errno) in ('ENOSPC', 'ENOTSUP', 'EOPNOTSUPP'):
+            # filesystem does not support xattr of this size
+            return False
+        raise
+    else:
+        supports_xattr_cached_val = True
+        return True
+    finally:
+        # clean up the tmpfile
+        os.close(fd)
+        os.unlink(tmppath)
+
+
+def skip_if_no_xattrs():
+    if not xattr_supported_check():
+        raise SkipTest('Large xattrs not supported in `%s`. Skipping test' %
+                       gettempdir())
