@@ -19,7 +19,6 @@ import unittest
 from contextlib import contextmanager
 from base64 import b64encode
 from time import time
-import mock
 
 from swift.common.middleware import tempauth as auth
 from swift.common.middleware.acl import format_acl
@@ -265,27 +264,58 @@ class TestAuth(unittest.TestCase):
         self.assertEqual(req.environ['swift.authorize'],
                          local_auth.denied_response)
 
-    def test_auth_with_s3_authorization(self):
+    def test_auth_with_s3_authorization_good(self):
         local_app = FakeApp()
         local_auth = auth.filter_factory(
             {'user_s3_s3': 'secret .admin'})(local_app)
-        req = self._make_request('/v1/AUTH_s3', environ={
+        req = self._make_request('/v1/s3:s3', environ={
+            'swift3.auth_details': {
+                'access_key': 's3:s3',
+                'signature': b64encode('sig'),
+                'string_to_sign': 't',
+                'check_signature': lambda secret: True}})
+        resp = req.get_response(local_auth)
+
+        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(local_app.calls, 1)
+        self.assertEqual(req.environ['PATH_INFO'], '/v1/AUTH_s3')
+        self.assertEqual(req.environ['swift.authorize'],
+                         local_auth.authorize)
+
+    def test_auth_with_s3_authorization_invalid(self):
+        local_app = FakeApp()
+        local_auth = auth.filter_factory(
+            {'user_s3_s3': 'secret .admin'})(local_app)
+        req = self._make_request('/v1/s3:s3', environ={
+            'swift3.auth_details': {
+                'access_key': 's3:s3',
+                'signature': b64encode('sig'),
+                'string_to_sign': 't',
+                'check_signature': lambda secret: False}})
+        resp = req.get_response(local_auth)
+
+        self.assertEqual(resp.status_int, 401)
+        self.assertEqual(local_app.calls, 1)
+        self.assertEqual(req.environ['PATH_INFO'], '/v1/s3:s3')
+        self.assertEqual(req.environ['swift.authorize'],
+                         local_auth.denied_response)
+
+    def test_auth_with_old_s3_details(self):
+        local_app = FakeApp()
+        local_auth = auth.filter_factory(
+            {'user_s3_s3': 'secret .admin'})(local_app)
+        req = self._make_request('/v1/s3:s3', environ={
             'swift3.auth_details': {
                 'access_key': 's3:s3',
                 'signature': b64encode('sig'),
                 'string_to_sign': 't'}})
+        resp = req.get_response(local_auth)
 
-        with mock.patch('hmac.new') as hmac:
-            hmac.return_value.digest.return_value = 'sig'
-            resp = req.get_response(local_auth)
-            self.assertEqual(hmac.mock_calls, [
-                mock.call('secret', 't', mock.ANY),
-                mock.call().digest()])
-
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(resp.status_int, 401)
         self.assertEqual(local_app.calls, 1)
+        self.assertEqual(req.environ['PATH_INFO'], '/v1/s3:s3')
         self.assertEqual(req.environ['swift.authorize'],
-                         local_auth.authorize)
+                         local_auth.denied_response)
 
     def test_auth_no_reseller_prefix_no_token(self):
         # Check that normally we set up a call back to our authorize.
