@@ -30,7 +30,7 @@ from swift.proxy import server as proxy
 import swift.proxy.controllers
 from swift.proxy.controllers.base import get_object_info
 from test.unit import FakeMemcache, debug_logger, FakeRing, \
-    fake_http_connect, patch_policies
+    fake_http_connect, patch_policies, skip_if_no_xattrs
 
 
 class FakeServerConnection(WSGIContext):
@@ -132,6 +132,7 @@ class TestObjectSysmeta(unittest.TestCase):
                              % (key, resp.headers))
 
     def setUp(self):
+        skip_if_no_xattrs()
         self.app = proxy.Application(None, FakeMemcache(),
                                      logger=debug_logger('proxy-ut'),
                                      account_ring=FakeRing(replicas=1),
@@ -307,11 +308,6 @@ class TestObjectSysmeta(unittest.TestCase):
         # test fast-post by issuing requests to the proxy app
         self._test_sysmeta_not_updated_by_POST(self.app)
 
-    def test_sysmeta_not_updated_by_POST_as_copy(self):
-        # test post-as-copy by issuing requests to the copy middleware app
-        self.copy_app.object_post_as_copy = True
-        self._test_sysmeta_not_updated_by_POST(self.copy_app)
-
     def test_sysmeta_updated_by_COPY(self):
         # check sysmeta is updated by a COPY in same way as user meta by
         # issuing requests to the copy middleware app
@@ -482,8 +478,3 @@ class TestObjectSysmeta(unittest.TestCase):
 
     def test_transient_sysmeta_replaced_by_PUT_or_POST(self):
         self._test_transient_sysmeta_replaced_by_PUT_or_POST(self.app)
-
-    def test_transient_sysmeta_replaced_by_PUT_or_POST_as_copy(self):
-        # test post-as-copy by issuing requests to the copy middleware app
-        self.copy_app.object_post_as_copy = True
-        self._test_transient_sysmeta_replaced_by_PUT_or_POST(self.copy_app)
